"""Un générateur de galleries"""
# %%
import logging
from pathlib import Path
from requests_html import HTMLSession
from jinja2 import Environment, FileSystemLoader, select_autoescape

logging.basicConfig(level=logging.DEBUG)
logger = logging.getLogger("GALLERY")

OUTPUT_FILENAME = Path("static/gallery_clean.html")
URL = "https://insight.nc/?page_id=1194"


def get_data():
    """Modèle: les données scrappées"""
    session = HTMLSession()
    response = session.get(URL)
    logger.info("Connection à %s: %i", URL, response.status_code)
    html = response.html

    elements = html.find(".elementor-widget-wrap", first=False)
    logger.info("la page contient %i elements", len(elements))

    images = []
    for elem in elements:
        img = elem.find(".elementor-image img", first=True)
        logger.debug("l'element <img> a comme source %s", img.attrs["src"])
        text = elem.find(".elementor-text-editor p", first=True)
        [ville, pays] = text.text.split("\n")
        logger.debug("l'element <p> contient %s / %s", ville, pays)
        images.append({"src": img.attrs["src"], "ville": ville, "pays": pays})

    logger.info("génération du dictionnaire len=%i", len(images))
    return images


def render(images, filename):
    """Génération de la vue"""
    env = Environment(loader=FileSystemLoader("./templates/"), autoescape=select_autoescape())
    template = env.get_template("gallery.jinja2.html")

    html_content = template.render(images=images)
    with open(filename, mode="w", encoding="utf-8") as file:
        file.write(html_content)
    logger.info("écriture du fichier %s", filename)


if __name__ == "__main__":
    the_images = get_data()
    render(the_images, OUTPUT_FILENAME)
