"""Un générateur de galleries"""

# %%

# installer avec la commande suivante
# pip install requests_html jinja2 --user

from requests_html import HTMLSession
from jinja2 import Environment, FileSystemLoader, select_autoescape

URL = "https://insight.nc/?page_id=1194"

# PARTIE 1 : analyse de la page ###################################################################


session = HTMLSession()
html = session.get(URL).html
print(f"{URL} accédée avec succès")

# avec html.find, on va choisir les éléments d'intérêt par des sélecteurs CSS

# les attributs src des images
img_elements = html.find("img.attachment-large")
print("liste des images recherchées avec find")
for img in img_elements:
    print(img.attrs["src"])

# les descriptions/villes
p_elements = html.find(".elementor-text-editor.elementor-clearfix p:first-child")
print("liste des éléments recherchés avec find")
for elt in p_elements:
    print(elt.text)

# on ne garde que la source des images et le texte des éléments p
images_urls = [img.attrs["src"] for img in img_elements]
images_locs = [elt.text.splitlines() for elt in p_elements]

# on génère une liste d'objets à afficher : le contenu/modèle passé à Jinja
images = [{"src": src, "ville": loc[0], "pays": loc[1]} for src, loc in zip(images_urls, images_locs)]
print("contenus")
for img in images:
    print(img)

# PARTIE 2 : génération par template ##############################################################

# on charge le template Jinja
env = Environment(loader=FileSystemLoader("templates/"), autoescape=select_autoescape())
template = env.get_template("gallery.jinja2.html")

# on rempli le template jinja avec les contenus
html_content = template.render(
    title="Ma page en live!", images=images, user="    romuald       "
)

# on enregistre le fichier produit sur le disque
SORTIE = "static/gallery_live.html"
with open(SORTIE, mode="w", encoding="utf-8") as file:
    file.write(html_content)

print(f"fichier {SORTIE} enregistré")
